@@ -1,6 +1,8 @@
 from .rsquared import RSquaredMetric
 from .mse import MSEMetric
 from .mae import MAEMetric
+from .rmse import RMSEMetric
 from .precision_recall import Precision, Recall
 from .f1 import F1Metric
-from .meaniou import MeanIoUMetric
\ No newline at end of file
+from .meaniou import MeanIoUMetric
+from .dice import DSCMetric
\ No newline at end of file
