@@ -8,4 +8,4 @@ class MAEMetric:
         x : torch.Tensor
         y : torch.Tensor
         """
-        return torch.mean((tensor1 - tensor2))
+        return torch.mean(torch.abs(tensor1 - tensor2))
